import { useRef, useCallback, useState, useEffect } from "react";
import { ChevronLeft, ChevronRight, X } from "lucide-react";

interface GalleryItem {
  image: string;
  title: string;
}

export default function GallerySection() {
  const galleryContainerRef = useRef<HTMLDivElement>(null);
  const [lightboxOpen, setLightboxOpen] = useState(false);
  const [currentImageIndex, setCurrentImageIndex] = useState(0);
  
  // Authentic gallery showcasing A2Z Stone Installation's work
  const galleryItems: GalleryItem[] = [
    {
      image: "/images/gallery/5de18e52-3f66-4017-b733-098044480587.webp",
      title: "Elegant Marble Waterfall Island"
    },
    {
      image: "/images/gallery/291a2b38-0249-4ff0-8256-5c77562fb6e7.webp",
      title: "Modern White Quartz Kitchen"
    },
    {
      image: "/images/gallery/3800b787-6c13-4689-87ff-3677116392aa.webp",
      title: "Luxury Granite Kitchen Countertops"
    },
    {
      image: "/images/gallery/c29d1b4e-0948-422b-ae17-aa871563d692.webp",
      title: "Contemporary Dark Stone Design"
    },
    {
      image: "/images/gallery/f2869167-1b83-441d-9048-513132001a42.webp",
      title: "Modern Kitchen Island Design"
    },
    {
      image: "/images/gallery/365619f4-0763-4c88-876a-d09288196672.webp",
      title: "Elegant Kitchen with Stone Countertops"
    },
    {
      image: "/images/gallery/b070a687-1f96-46ad-9818-4c41136a5241.webp",
      title: "Complete Kitchen Stone Installation"
    },
    {
      image: "/images/gallery/IMG_5304.webp",
      title: "Custom Stone Entertainment Center"
    }
  ];

  const openLightbox = useCallback((index: number) => {
    setCurrentImageIndex(index);
    setLightboxOpen(true);
    document.body.style.overflow = 'hidden';
  }, []);

  const closeLightbox = useCallback(() => {
    setLightboxOpen(false);
    document.body.style.overflow = 'unset';
  }, []);

  const nextImage = useCallback(() => {
    setCurrentImageIndex((prev) => (prev + 1) % galleryItems.length);
  }, [galleryItems.length]);

  const prevImage = useCallback(() => {
    setCurrentImageIndex((prev) => (prev - 1 + galleryItems.length) % galleryItems.length);
  }, [galleryItems.length]);

  const scrollLeft = useCallback(() => {
    if (galleryContainerRef.current) {
      const scrollWidth = galleryContainerRef.current.clientWidth;
      galleryContainerRef.current.scrollBy({ left: -scrollWidth * 0.8, behavior: 'smooth' });
    }
  }, []);

  const scrollRight = useCallback(() => {
    if (galleryContainerRef.current) {
      const scrollWidth = galleryContainerRef.current.clientWidth;
      galleryContainerRef.current.scrollBy({ left: scrollWidth * 0.8, behavior: 'smooth' });
    }
  }, []);

  const handleKeyDown = useCallback((e: KeyboardEvent) => {
    if (!lightboxOpen) return;
    
    switch (e.key) {
      case 'ArrowLeft':
        e.preventDefault();
        prevImage();
        break;
      case 'ArrowRight':
        e.preventDefault();
        nextImage();
        break;
      case 'Escape':
        e.preventDefault();
        closeLightbox();
        break;
    }
  }, [lightboxOpen, nextImage, prevImage, closeLightbox]);

  // Add keyboard event listeners for lightbox
  useEffect(() => {
    if (lightboxOpen) {
      document.addEventListener('keydown', handleKeyDown);
      return () => document.removeEventListener('keydown', handleKeyDown);
    }
  }, [lightboxOpen, handleKeyDown]);

  return (
    <section id="gallery" className="py-24 bg-gray-50">
      <div className="container mx-auto px-4">
        <div className="text-center mb-16 fade-in">
          <h2 className="text-4xl md:text-5xl font-bold text-primary mb-6">
            Our Gallery
          </h2>
          <p className="text-lg text-gray-600 max-w-3xl mx-auto">
            Explore our stunning collection of stone installations. From luxurious kitchen countertops to elegant bathroom vanities, 
            each project represents our commitment to exceptional craftsmanship and attention to detail.
          </p>
        </div>
        
        <div className="relative">
          <div 
            ref={galleryContainerRef}
            className="flex gap-4 overflow-x-auto pb-4 scrollbar-hide gallery-container"
            style={{ scrollbarWidth: 'none', msOverflowStyle: 'none' }}
          >
            {galleryItems.map((item, index) => (
              <div 
                key={index}
                className="flex-shrink-0 w-80 h-96 relative rounded-xl overflow-hidden shadow-lg cursor-pointer group hover:shadow-xl transition-all duration-300"
                onClick={() => openLightbox(index)}
              >
                <img 
                  src={item.image} 
                  alt={item.title} 
                  className="w-full h-full object-cover group-hover:scale-110 transition-transform duration-300"
                  loading={index < 3 ? "eager" : "lazy"}
                  width="450"
                  height="450"
                  decoding="async"
                  style={{ aspectRatio: '1/1' }}
                />
                
                <div className="absolute inset-0 bg-gradient-to-t from-black/80 via-black/20 to-transparent group-hover:from-black/90 transition-all duration-300">
                  <div className="absolute top-4 left-4 right-4">
                    <div className="bg-accent text-primary text-xs font-bold px-3 py-1 rounded-full inline-block">
                      PROFESSIONAL INSTALLATION
                    </div>
                  </div>
                </div>
                
                <div className="absolute bottom-0 left-0 right-0 p-4 md:p-6 transform translate-y-2 group-hover:translate-y-0 transition-transform duration-300">
                  <span className="text-white font-semibold text-lg md:text-xl block">{item.title}</span>
                  <span className="text-accent text-sm mt-2 opacity-0 group-hover:opacity-100 transition-opacity duration-500 delay-100 font-medium">✨ Click to view full size</span>
                </div>
              </div>
            ))}
          </div>
          
          <button 
            onClick={scrollLeft}
            className="absolute left-2 top-1/2 transform -translate-y-1/2 bg-white p-3 rounded-full shadow-lg z-20 focus:outline-none hover:bg-accent hover:text-white transition-all duration-200 border border-gray-200"
            aria-label="Previous images"
          >
            <ChevronLeft className="h-5 w-5" />
          </button>
          
          <button 
            onClick={scrollRight}
            className="absolute right-2 top-1/2 transform -translate-y-1/2 bg-white p-3 rounded-full shadow-lg z-20 focus:outline-none hover:bg-accent hover:text-white transition-all duration-200 border border-gray-200"
            aria-label="Next images"
          >
            <ChevronRight className="h-5 w-5" />
          </button>
        </div>
        
        <div className="flex justify-center mt-10">
          <a 
            href="/gallery" 
            className="bg-accent hover:bg-white text-primary font-bold py-4 px-10 rounded-lg transition-all duration-200 inline-flex items-center gap-2 shadow-lg hover:shadow-xl hover:shadow-accent/30 group hover-scale"
          >
            See More
            <svg className="w-5 h-5 transform group-hover:translate-x-1 transition-transform duration-300" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
            </svg>
          </a>
        </div>
      </div>

      {/* Lightbox Modal */}
      {lightboxOpen && (
        <div
          className="fixed inset-0 bg-black/90 z-50 flex items-center justify-center fade-in"
          onClick={closeLightbox}
          role="dialog"
          aria-modal="true"
          aria-labelledby="lightbox-title"
          aria-describedby="lightbox-description"
        >
          {/* Close Button */}
          <button
            onClick={closeLightbox}
            className="absolute top-4 right-4 text-white hover:text-accent transition-colors z-60 bg-black/60 backdrop-blur-sm rounded-full p-3 border border-white/20 touch-manipulation focus:outline-none focus:ring-2 focus:ring-accent focus:ring-offset-2 focus:ring-offset-black"
            aria-label="Close lightbox"
          >
            <X className="h-6 w-6 sm:h-8 sm:w-8" />
          </button>

          {/* Previous Button */}
          <button
            onClick={(e) => {
              e.stopPropagation();
              prevImage();
            }}
            className="absolute left-4 top-1/2 transform -translate-y-1/2 text-white hover:text-accent transition-colors z-[70] bg-black/70 backdrop-blur-sm rounded-full p-4 border border-white/20 touch-manipulation focus:outline-none focus:ring-2 focus:ring-accent focus:ring-offset-2 focus:ring-offset-black shadow-lg"
            aria-label="Previous image"
          >
            <ChevronLeft className="h-6 w-6 sm:h-8 sm:w-8" />
          </button>

          {/* Next Button */}
          <button
            onClick={(e) => {
              e.stopPropagation();
              nextImage();
            }}
            className="absolute right-4 top-1/2 transform -translate-y-1/2 text-white hover:text-accent transition-colors z-[70] bg-black/70 backdrop-blur-sm rounded-full p-4 border border-white/20 touch-manipulation focus:outline-none focus:ring-2 focus:ring-accent focus:ring-offset-2 focus:ring-offset-black shadow-lg"
            aria-label="Next image"
          >
            <ChevronRight className="h-6 w-6 sm:h-8 sm:w-8" />
          </button>

          {/* Image Container */}
          <div
            className="relative max-w-[95vw] max-h-[85vh] flex flex-col items-center px-6 py-2 sm:px-8 sm:py-4 fade-in"
            style={{
              scrollbarWidth: 'none',
              msOverflowStyle: 'none',
            }}
            onClick={(e) => e.stopPropagation()}
          >
            <img
              src={galleryItems[currentImageIndex].image}
              alt={galleryItems[currentImageIndex].title}
              className="max-w-full max-h-[60vh] sm:max-h-[70vh] object-contain rounded-lg shadow-2xl transition-all duration-300 ease-in-out"
              key={currentImageIndex}
            />
            
            {/* Title Overlay - Centered under the picture */}
            <div className="mt-4 max-w-full">
              <div className="bg-black/70 backdrop-blur-sm rounded-lg px-4 py-2 border border-white/20 text-center transition-all duration-300">
                <h3 id="lightbox-title" className="text-white text-sm sm:text-base font-semibold mb-1 drop-shadow-lg">
                  {galleryItems[currentImageIndex].title}
                </h3>
                <p id="lightbox-description" className="text-accent text-xs sm:text-sm font-medium drop-shadow-lg">
                  {currentImageIndex + 1} of {galleryItems.length}
                </p>
              </div>
            </div>
          </div>


        </div>
      )}
    </section>
  );
}